@@ -11,7 +11,7 @@ use Text::Unidecode;
 use Carp;
 
 use vars qw($VERSION);
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 use 5.008000;
 
@@ -140,8 +140,8 @@ This module provides an easy and convinient way to encode names with various
 phonetic algorithms. It acts as a wrapper arround other phonetic algorithm
 modules like L<Text::Metaphone>, L<Text::DoubleMetaphone>, L<Text::Soundex>
 and also implements some other algorithms such as 
-L<Text::Phonetic::DaitchMokotoff>, L<Text::Phonetic::Koeln> and 
-L<Text::Phonetic::Phonix>.
+L<Text::Phonetic::DaitchMokotoff>, L<Text::Phonetic::Koeln>,
+L<Text::Phonetic::Phonem> and L<Text::Phonetic::Phonix>.
 
 The module can easily be subclassed.
 
@@ -151,11 +151,12 @@ The module can easily be subclassed.
 
  $obj = Text::Phonetic::SUBCLASS->new({ %PARAMETERS })
  
-You can pass arbitrary attributes to the constructor. The only global attribute
-is C<unidecode> which defaults to 1 if not set. This attribute controlls if 
-non-latin characters should be transliterated to A-Z (L<Text::Unidecode>).
+You can pass arbitrary attributes to the constructor. The only global 
+attribute is C<unidecode> which defaults to 1 if not set. This attribute 
+controlls if non-latin characters should be transliterated to A-Z 
+(see also L<Text::Unidecode>).
 
-Additional attributes may be defined by subclasses.
+Additional attributes may be defined by the various implementation classes.
 
 =head2 encode
 
@@ -173,17 +174,17 @@ array reference depending on the caller context and parameters.
  $RETURN_CODE = $obj->compare($STRING1,$STRING2);
  
 The return code is an integer between 100 and 0 indicating the likelihood that
-the to results are the same. 100 usually means that the strings are completely
+the to results are the same. 100  means that the strings are completely
 identical. 99 means that the strings match after all non-latin characters
-have been transliterated. Values in between 98 and 0 mean that the given strings
-likely match. 0 means that the used alogorithm couldn't match the two strings at
-all.
+have been transliterated. Values in between 98 and 1 usually mean that the given 
+strings match. 0 means that the used alogorithm couldn't match the two 
+strings at all.
 C<compare> is a shortcut to the C<$obj-&gt;_do_compare($CODE1,$CODE2)> method. 
 
 =head1 SUBLCASSING
 
 You can easily subclass Text::Phonetic and add your own phonetic algorithm.
-All subclasses have to use Text::Phonetic as their base class, and the 
+All subclasses must use Text::Phonetic as their base class, and the 
 following methods need to be implemented:
 
 =head2 _do_encode
@@ -207,7 +208,7 @@ by C<_do_encode> and returns an integer value between 98 and 0
 The object is a simple Hash reference containing all parameters passed during
 construction.
 
-=head2 Helper functions
+=head2 Helper class methods
 
 =over 2
 
@@ -246,7 +247,6 @@ changes.
 =head1 COPYRIGHT
 
 Text::Phonetic is Copyright (c) 2006,2007 Maroš. Kollár.
-All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
